@@ -17,7 +17,7 @@
     use constant _MATH_MPC_T    => 10;
 
 use subs qw( __GNU_MP_VERSION __GNU_MP_VERSION_MINOR __GNU_MP_VERSION_PATCHLEVEL
-             __GNU_MP_RELEASE __GMP_CC __GMP_CFLAGS);
+             __GNU_MP_RELEASE __GMP_CC __GMP_CFLAGS GMP_LIMB_BITS GMP_NAIL_BITS);
 
 use overload
     '++'   => \&overload_inc,
@@ -50,25 +50,25 @@ use overload
 __GNU_MP_VERSION __GNU_MP_VERSION_MINOR __GNU_MP_VERSION_PATCHLEVEL
 __GNU_MP_RELEASE __GMP_CC __GMP_CFLAGS
 Rmpf_abs Rmpf_add Rmpf_add_ui Rmpf_ceil Rmpf_clear Rmpf_clear_mpf Rmpf_clear_ptr
-Rmpf_cmp Rmpf_cmp_d Rmpf_cmp_si Rmpf_cmp_ui 
+Rmpf_cmp Rmpf_cmp_d Rmpf_cmp_si Rmpf_cmp_ui
 Rmpf_deref2 Rmpf_div Rmpf_div_2exp Rmpf_div_ui
-Rmpf_eq Rmpf_fits_sint_p Rmpf_fits_slong_p Rmpf_fits_sshort_p Rmpf_fits_uint_p 
+Rmpf_eq Rmpf_fits_sint_p Rmpf_fits_slong_p Rmpf_fits_sshort_p Rmpf_fits_uint_p
 Rmpf_fits_ulong_p Rmpf_fits_ushort_p Rmpf_floor Rmpf_fprintf
-Rmpf_get_d Rmpf_get_d_2exp 
-Rmpf_get_default_prec Rmpf_get_prec Rmpf_get_si Rmpf_get_str Rmpf_get_ui 
-Rmpf_init Rmpf_init2 Rmpf_init2_nobless Rmpf_init_nobless Rmpf_init_set 
-Rmpf_init_set_d Rmpf_init_set_d_nobless Rmpf_init_set_nobless Rmpf_init_set_si 
-Rmpf_init_set_si_nobless Rmpf_init_set_str Rmpf_init_set_str_nobless 
+Rmpf_get_d Rmpf_get_d_2exp
+Rmpf_get_default_prec Rmpf_get_prec Rmpf_get_si Rmpf_get_str Rmpf_get_ui
+Rmpf_init Rmpf_init2 Rmpf_init2_nobless Rmpf_init_nobless Rmpf_init_set
+Rmpf_init_set_d Rmpf_init_set_d_nobless Rmpf_init_set_nobless Rmpf_init_set_si
+Rmpf_init_set_si_nobless Rmpf_init_set_str Rmpf_init_set_str_nobless
 Rmpf_init_set_ui Rmpf_init_set_ui_nobless Rmpf_inp_str
 TRmpf_inp_str
-Rmpf_integer_p Rmpf_mul 
-Rmpf_mul_2exp Rmpf_mul_ui Rmpf_neg Rmpf_out_str 
+Rmpf_integer_p Rmpf_mul
+Rmpf_mul_2exp Rmpf_mul_ui Rmpf_neg Rmpf_out_str
 TRmpf_out_str
-Rmpf_pow_ui Rmpf_printf 
-Rmpf_random2 Rmpf_reldiff Rmpf_set Rmpf_set_d Rmpf_set_default_prec Rmpf_set_prec 
-Rmpf_set_prec_raw Rmpf_set_q Rmpf_set_si Rmpf_set_str Rmpf_set_ui Rmpf_set_z 
+Rmpf_pow_ui Rmpf_printf
+Rmpf_random2 Rmpf_reldiff Rmpf_set Rmpf_set_d Rmpf_set_default_prec Rmpf_set_prec
+Rmpf_set_prec_raw Rmpf_set_q Rmpf_set_si Rmpf_set_str Rmpf_set_ui Rmpf_set_z
 Rmpf_sgn Rmpf_sprintf Rmpf_snprintf
-Rmpf_sqrt Rmpf_sqrt_ui Rmpf_sub Rmpf_sub_ui Rmpf_swap Rmpf_trunc 
+Rmpf_sqrt Rmpf_sqrt_ui Rmpf_sub Rmpf_sub_ui Rmpf_swap Rmpf_trunc
 Rmpf_ui_div Rmpf_ui_sub Rmpf_urandomb
 fgmp_randseed fgmp_randseed_ui fgmp_randclear
 fgmp_randinit_default fgmp_randinit_mt fgmp_randinit_lc_2exp fgmp_randinit_lc_2exp_size
@@ -76,32 +76,32 @@ fgmp_randinit_set fgmp_randinit_default_nobless fgmp_randinit_mt_nobless
 fgmp_randinit_lc_2exp_nobless fgmp_randinit_lc_2exp_size_nobless fgmp_randinit_set_nobless
 fgmp_urandomb_ui fgmp_urandomm_ui
     );
-    our $VERSION = '0.39';
-    $VERSION = eval $VERSION;
+    our $VERSION = '0.41';
+    #$VERSION = eval $VERSION;
 
     DynaLoader::bootstrap Math::GMPf $VERSION;
 
     %Math::GMPf::EXPORT_TAGS =(mpf => [qw(
 Rmpf_abs Rmpf_add Rmpf_add_ui Rmpf_ceil Rmpf_clear Rmpf_clear_mpf Rmpf_clear_ptr
-Rmpf_cmp Rmpf_cmp_d Rmpf_cmp_si Rmpf_cmp_ui 
+Rmpf_cmp Rmpf_cmp_d Rmpf_cmp_si Rmpf_cmp_ui
 Rmpf_deref2 Rmpf_div Rmpf_div_2exp Rmpf_div_ui
-Rmpf_eq Rmpf_fits_sint_p Rmpf_fits_slong_p Rmpf_fits_sshort_p Rmpf_fits_uint_p 
+Rmpf_eq Rmpf_fits_sint_p Rmpf_fits_slong_p Rmpf_fits_sshort_p Rmpf_fits_uint_p
 Rmpf_fits_ulong_p Rmpf_fits_ushort_p Rmpf_floor Rmpf_fprintf
-Rmpf_get_d Rmpf_get_d_2exp 
-Rmpf_get_default_prec Rmpf_get_prec Rmpf_get_si Rmpf_get_str Rmpf_get_ui 
-Rmpf_init Rmpf_init2 Rmpf_init2_nobless Rmpf_init_nobless Rmpf_init_set 
-Rmpf_init_set_d Rmpf_init_set_d_nobless Rmpf_init_set_nobless Rmpf_init_set_si 
-Rmpf_init_set_si_nobless Rmpf_init_set_str Rmpf_init_set_str_nobless 
-Rmpf_init_set_ui Rmpf_init_set_ui_nobless Rmpf_inp_str 
+Rmpf_get_d Rmpf_get_d_2exp
+Rmpf_get_default_prec Rmpf_get_prec Rmpf_get_si Rmpf_get_str Rmpf_get_ui
+Rmpf_init Rmpf_init2 Rmpf_init2_nobless Rmpf_init_nobless Rmpf_init_set
+Rmpf_init_set_d Rmpf_init_set_d_nobless Rmpf_init_set_nobless Rmpf_init_set_si
+Rmpf_init_set_si_nobless Rmpf_init_set_str Rmpf_init_set_str_nobless
+Rmpf_init_set_ui Rmpf_init_set_ui_nobless Rmpf_inp_str
 TRmpf_inp_str
-Rmpf_integer_p Rmpf_mul 
-Rmpf_mul_2exp Rmpf_mul_ui Rmpf_neg Rmpf_out_str 
+Rmpf_integer_p Rmpf_mul
+Rmpf_mul_2exp Rmpf_mul_ui Rmpf_neg Rmpf_out_str
 TRmpf_out_str
-Rmpf_pow_ui Rmpf_printf 
-Rmpf_random2 Rmpf_reldiff Rmpf_set Rmpf_set_d Rmpf_set_default_prec Rmpf_set_prec 
-Rmpf_set_prec_raw Rmpf_set_q Rmpf_set_si Rmpf_set_str Rmpf_set_ui Rmpf_set_z 
+Rmpf_pow_ui Rmpf_printf
+Rmpf_random2 Rmpf_reldiff Rmpf_set Rmpf_set_d Rmpf_set_default_prec Rmpf_set_prec
+Rmpf_set_prec_raw Rmpf_set_q Rmpf_set_si Rmpf_set_str Rmpf_set_ui Rmpf_set_z
 Rmpf_sgn Rmpf_sprintf Rmpf_snprintf
-Rmpf_sqrt Rmpf_sqrt_ui Rmpf_sub Rmpf_sub_ui Rmpf_swap Rmpf_trunc 
+Rmpf_sqrt Rmpf_sqrt_ui Rmpf_sub Rmpf_sub_ui Rmpf_swap Rmpf_trunc
 Rmpf_ui_div Rmpf_ui_sub Rmpf_urandomb
 fgmp_randseed fgmp_randseed_ui fgmp_randclear
 fgmp_randinit_default fgmp_randinit_mt fgmp_randinit_lc_2exp fgmp_randinit_lc_2exp_size
@@ -115,14 +115,14 @@ sub dl_load_flags {0} # Prevent DynaLoader from complaining and croaking
 sub new {
 
     # This function caters for 2 possibilities:
-    # 1) that 'new' has been called OOP style - in which 
+    # 1) that 'new' has been called OOP style - in which
     #    case there will be a maximum of 3 args
     # 2) that 'new' has been called as a function - in
     #    which case there will be a maximum of 2 args.
     # If there are no args, then we just want to return an
     # initialized Math::GMPf object
     if(!@_) {return Rmpf_init()}
-   
+
     if(@_ > 3) {die "Too many arguments supplied to new()"}
 
     # If 'new' has been called OOP style, the first arg is the string
@@ -134,7 +134,7 @@ sub new {
     if(!ref($_[0]) && $_[0] eq "Math::GMPf") {
       shift;
       if(!@_) {return Rmpf_init()}
-      } 
+      }
 
     # @_ can now contain a maximum of 2 args - the value, and iff the value is
     # a string, (optionally) the base of the numeric string.
@@ -167,7 +167,7 @@ sub new {
       return Rmpf_init_set_d($arg1);
 
     }
-    
+
     if($type == _POK_T) {
       if(@_ > 1) {die "Too many arguments supplied to new() - expected no more than two"}
       $base = shift if @_;
@@ -250,7 +250,7 @@ sub _rewrite {
     shift(@split);
 
     my $start = 0;
-    
+
     for(@split) {
        push(@ret, substr($_[0], $start, $_ - $start));
        $start = $_;
@@ -306,6 +306,8 @@ sub __GNU_MP_VERSION_PATCHLEVEL {return ___GNU_MP_VERSION_PATCHLEVEL()}
 sub __GNU_MP_RELEASE {return ___GNU_MP_RELEASE()}
 sub __GMP_CC {return ___GMP_CC()}
 sub __GMP_CFLAGS {return ___GMP_CFLAGS()}
+sub GMP_LIMB_BITS {return _GMP_LIMB_BITS()}
+sub GMP_NAIL_BITS {return _GMP_NAIL_BITS()}
 
 *fgmp_randseed =                      \&Math::GMPf::Random::Rgmp_randseed;
 *fgmp_randseed_ui =                   \&Math::GMPf::Random::Rgmp_randseed_ui;
@@ -380,7 +382,7 @@ __END__
    .
 
    # print out the value held by $bn1 (in octal):
-   print Rmpf_get_str($bn1, 8, 0), "\n"; 
+   print Rmpf_get_str($bn1, 8, 0), "\n";
 
    # print out the value held by $bn1 (in decimal):
    print Rmpf_get_str($bn1, 10, 0);
@@ -398,14 +400,14 @@ __END__
    DESTROY() function whenever they go out of scope.
 
    For each Rmpf_init* fnction there is a corresponding
-   Rmpf_init*_nobless function. If you wish you can 
+   Rmpf_init*_nobless function. If you wish you can
    create unblessed objects using these functions.
    It will then be up to you to clean up the memory
    associated with these objects by calling
    Rmpf_clear($op), for each object. Alternatively the objects
    will be cleaned up when the script ends. I don't know
    why you would want to create unblessed objects. The
-   point is that you can if you want to.  
+   point is that you can if you want to.
 
 =head1 FUNCTIONS
 
@@ -414,7 +416,7 @@ __END__
    These next 3 functions are demonstrated above:
    $rop   = Rmpf_init_set_str($str, $base); # 1 < abs($base) < 63
    $rop   = Rmpf_init2($bits); # $bits > 0
-   $str = Rmpf_get_str($r, $base, $digits); # 1 < abs($base) < 63 
+   $str = Rmpf_get_str($r, $base, $digits); # 1 < abs($base) < 63
    The third argument to Rmpf_get_str() specifies the number
    of digits required to be output. Up to $digits digits
    will be generated.  Trailing zeros are not returned.  No
@@ -432,7 +434,7 @@ __END__
    (or their '_nobless' counterpart).
    They are in fact references to GMP structures.
    The "$rop" argument(s) contain the result(s) of the calculation
-   being done, the "$op" argument(s) being the input(s) into that 
+   being done, the "$op" argument(s) being the input(s) into that
    calculation.
    Generally, $rop, $op1, $op2, etc. can be the same perl variable,
    though usually they will be distinct perl variables referencing
@@ -443,11 +445,11 @@ __END__
    as $r1 += $r1. Otoh, Rmpf_add($r1, $r2, $r3), where each of the
    arguments is a different reference to a different GMP structure
    would add $r2 to $r3 and store the result in $r1. Think of it as
-   $r1 = $r2 + $r3. Mostly, the first argument is the argument that 
+   $r1 = $r2 + $r3. Mostly, the first argument is the argument that
    stores the result and subsequent arguments provide the input values.
    Exceptions to this can be found in some of the functions that
-   actually return a value. 
-   Like I say, see the GMP manual for details. I hope it's 
+   actually return a value.
+   Like I say, see the GMP manual for details. I hope it's
    intuitively obvious or quickly becomes so. Also see the test
    suite that comes with the distro for some examples of usage.
 
@@ -473,7 +475,7 @@ __END__
 
    Normally, a variable should be initialized once only or at least be
    cleared, using `Rmpf_clear', between initializations.
-   'DESTROY' (which calls 'Rmpf_clear') is automatically called on 
+   'DESTROY' (which calls 'Rmpf_clear') is automatically called on
    blessed objects whenever they go out of scope.
 
    First read the section 'MEMORY MANAGEMENT' (above).
@@ -481,7 +483,7 @@ __END__
    $bits = Rmpf_get_default_prec();
     Return the current default default precision.
 
-   Rmpf_set_default_prec($bits); 
+   Rmpf_set_default_prec($bits);
     Set the default precision to be *at least* $bits bits.  All
     subsequent calls to `Rmpf_init' will use this precision, but
     previously initialized variables are unaffected.
@@ -498,7 +500,7 @@ __END__
    $rop = Rmpf_init2($bits);
    $rop = Rmpf_init2_nobless($bits);
      Initialize $rop to 0 and set its precision to be
-     *at least* $bits bits. 
+     *at least* $bits bits.
 
    $bits = Rmpf_get_prec($op);
     Return the current precision of $op, in bits.
@@ -511,7 +513,7 @@ __END__
 
    Rmpf_set_prec_raw($rop, $bits);
     Set the precision of $rop to be *at least* $bits bits, without
-    changing the memory allocated. $bits must be no more than the 
+    changing the memory allocated. $bits must be no more than the
     allocated precision for $rop, that being the precision when $rop
     was initialized, or in the most recent `Rmpf_set_prec'.
     The value in $rop is unchanged, and in particular if it had a
@@ -520,7 +522,7 @@ __END__
     Before calling `Rmpf_clear' (which will happen when a blessed
     Math::GMPf object goes out of scope) or the full `Rmpf_set_prec',
     another `Rmpf_set_prec_raw' call must be made to restore $rop to
-    its original allocated precision.  Failing to do so will have 
+    its original allocated precision.  Failing to do so will have
     unpredictable results.
     `Rmpf_get_prec' can be used before `Rmpf_set_prec_raw' to get the
     original allocated precision.  After `Rmpf_set_prec_raw' it
@@ -535,12 +537,12 @@ __END__
 
    ASSIGNMENT FUNCTIONS
 
-   Rmpf_set($rop, $op); 
+   Rmpf_set($rop, $op);
    Rmpf_set_ui($rop, $ui);
    Rmpf_set_si($rop, $si);
    Rmpf_set_d($rop, $double);
    Rmpf_set_z($rop, $z); # $z is a Math::GMPz object.
-   Rmpf_set_q($rop, $q); # $q is a Math::GMPq object. 
+   Rmpf_set_q($rop, $q); # $q is a Math::GMPq object.
     Set the value of $rop from the 2nd arg.
 
    Rmpf_set_str($rop, $str, $base);
@@ -548,18 +550,18 @@ __END__
     the form `M@N' or, if the base is 10 or less, alternatively
     `MeN'. `M' is the mantissa and `N' is the exponent. The mantissa
     is always in the specified base. The exponent is either in the
-    specified base or, if base is negative, in decimal. 
+    specified base or, if base is negative, in decimal.
     The argument $base may be in the ranges 2 to 62, or -62 to -2.
     Negative values are used to specify that the exponent is in
     decimal. For bases up to 36, case is ignored; upper-case and
     lower-case letters have the same value; for bases 37 to 62,
     upper-case letter represent the usual 10..35 while lower-case
-    letter represent 36..61. 
-    Unlike the corresponding mpz function, the base will not be 
+    letter represent 36..61.
+    Unlike the corresponding mpz function, the base will not be
     determined from the leading characters of the string if base is 0.
-    This is so that numbers like `0.23' are not interpreted as octal. 
+    This is so that numbers like `0.23' are not interpreted as octal.
     This function croaks if the entire string is not a valid number
-    in base $base. 
+    in base $base.
 
    Rmpf_swap($rop1, $rop2);
     Swap $rop1 and $rop2. Both the values and the
@@ -570,7 +572,7 @@ __END__
    COMBINED INITIALIZATION AND ASSIGNMENT
 
    NOTE: Do NOT use these functions if $rop has already
-   been initialised. Instead use the Rmpz_set* functions 
+   been initialised. Instead use the Rmpz_set* functions
    in 'Assignment Functions' (above)
 
    First read the section 'MEMORY MANAGEMENT' (above).
@@ -580,7 +582,7 @@ __END__
    $rop = new Math::GMPf($arg);
     Returns a Math::GMPf object with the value of $arg, with default
     precision. $arg can be either a number (signed integer, unsigned
-    integer, signed fraction or unsigned fraction) or a string that 
+    integer, signed fraction or unsigned fraction) or a string that
     represents a numeric value. If $arg is a string, an optional
     additional argument that specifies the base of the number can
     be supplied to new(). If $arg is a string and no additional
@@ -627,7 +629,7 @@ __END__
 
    $str = Rmpf_get_str($op, $base, $digits);
     Convert $op to a string of digits in base $base. $base can
-    be 2 to 62.  Up to $digits digits will be generated. 
+    be 2 to 62.  Up to $digits digits will be generated.
     Trailing zeros are not returned.  No more digits than can be
     accurately represented by $op are ever generated.  If $digits
     is 0 then that accurate maximum number of digits are generated.
@@ -658,7 +660,7 @@ __END__
    Rmpf_mul_ui($rop, $op, $ui);
     $rop = 2nd arg * 3rd arg.
 
-   Rmpf_div($rop, $op1, $op2); 
+   Rmpf_div($rop, $op1, $op2);
    Rmpf_ui_div($rop, $ui, $op);
    Rmpf_div_ui($rop, $op, $ui);
     $rop = 2nd arg / 3rd arg.
@@ -670,7 +672,7 @@ __END__
    Rmpf_pow_ui($rop, $op, $ui);
     $ROP = $OP ** $ui.
 
-   Rmpf_neg($rop, $op); 
+   Rmpf_neg($rop, $op);
     $rop = -$op.
 
    Rmpf_abs($rop, $op);
@@ -682,16 +684,16 @@ __END__
    Rmpf_div_2exp($rop, $op, $ui);
     $rop = $op / (2 ** $ui).
 
-   #################### 
+   ####################
 
    COMPARISON FUNCTIONS
 
-   $si = Rmpf_cmp($op1, $op2); 
+   $si = Rmpf_cmp($op1, $op2);
    $si = Rmpf_cmp_ui($op, $ui);
    $si = Rmpf_cmp_si($op, $si);
    $si = Rmpf_cmp_d($op, $double);
-    Compare 1st arg and 2nd arg.  Return a positive value if 
-    1st arg >  2nd arg, zero if 1st arg = 2nd arg, and a 
+    Compare 1st arg and 2nd arg.  Return a positive value if
+    1st arg >  2nd arg, zero if 1st arg = 2nd arg, and a
     negative value if 1st arg < 2nd arg.
 
    Rmpf_eq($op1, $op2, $bits);
@@ -714,7 +716,7 @@ __END__
    $bytes_read = Rmpf_inp_str($rop, $base);
     BEST TO USE TRmpf_inp_str INSTEAD.
     Read a string in base $base from STDIN, and put the read
-    float in $rop. The string is of the form `M@N' or, if 
+    float in $rop. The string is of the form `M@N' or, if
     $base is 10 or less, alternatively `MeN'.  `M' is the
     mantissa and `N' is the exponent.  The mantissa is always
     in the specified base. The exponent is either in the
@@ -740,7 +742,7 @@ __END__
     BEST TO USE TRmpf_out_str INSTEAD.
     Print $op to stream, as a string of digits. Return the number of
     bytes written, or if an error occurred, return 0. The mantissa is
-    prefixed with an `0.' and is in the given base, which may vary 
+    prefixed with an `0.' and is in the given base, which may vary
     from 2 to 62 or from -2 to -36. An exponent is then printed,
     separated by an `e', or if the base is greater than 10 then by an
     `@'. The exponent is always in decimal. The decimal point follows
@@ -749,10 +751,10 @@ __END__
     -2..-36, digits and upper-case letters are used; for 37..62, digits,
     upper-case letters, and lower-case letters (in that significance
     order) are used. Up to $digits will be printed from the mantissa,
-    except that no more digits than are accurately representable by $op 
-    will be printed. $digits can be 0 to select that accurate maximum. 
+    except that no more digits than are accurately representable by $op
+    will be printed. $digits can be 0 to select that accurate maximum.
     The optional last argument ($suffix) is a string (eg "\n") that
-    will be appended to the output. The optional first argument 
+    will be appended to the output. The optional first argument
     ($prefix) is a string that will be prepended to the output. Note
     that either none, one, or both, of $prefix and $suffix may be
     supplied. ($bytes_written does not include the number of bytes in
@@ -771,8 +773,8 @@ __END__
 
    MISCELLANEOUS FUNCTIONS
 
-   Rmpf_ceil($rop, $op); 
-   Rmpf_floor($rop, $op); 
+   Rmpf_ceil($rop, $op);
+   Rmpf_floor($rop, $op);
    Rmpf_trunc($rop, $op);
     Set $rop to $op rounded to an integer.  `Rmpf_ceil' rounds to the
     next higher integer, `mpf_floor' to the next lower, and
@@ -781,9 +783,9 @@ __END__
    $bool = Rmpf_integer_p($op);
     Return non-zero if $op is an integer.
 
-   $bool = Rmpf_fits_ulong_p($op); 
+   $bool = Rmpf_fits_ulong_p($op);
    $bool = Rmpf_fits_slong_p($op);
-   $bool = Rmpf_fits_uint_p($op); 
+   $bool = Rmpf_fits_uint_p($op);
    $bool = Rmpf_fits_sint_p($op);
    $bool = Rmpf_fits_ushort_p($op);
    $bool = Rmpf_fits_sshort_p($op);
@@ -792,11 +794,11 @@ __END__
 
    #######################
 
-   RANDOM NUMBER FUNCTIONS 
+   RANDOM NUMBER FUNCTIONS
 
-   In the random number functions, @r is an array of 
+   In the random number functions, @r is an array of
    Math::GMPf objects (one for each random number that is
-   required). $how_many is the number of random numbers you 
+   required). $how_many is the number of random numbers you
    want and must be equal to scalar(@r). $bits is simply the
    number of random bits required. Before calling the random
    number functions, $state must be initialised and seeded.
@@ -806,7 +808,7 @@ __END__
     better alternatives listed immediately below, anyway.)
     Initialises and seeds $state, ready for use with the random
     number functions. However, $state has not been blessed into
-    any package, and therefore does not get cleaned up when it 
+    any package, and therefore does not get cleaned up when it
     goes out of scope. To avoid memory leaks you therefore need
     to call 'Math::GMPz::rand_clear($state);' once you have
     finished with it and before it goes out of scope. Also, it
@@ -841,10 +843,10 @@ __END__
     X = ($mpz*X + $ui) mod (2 ** $m2exp). The low bits of X in this
     algorithm are not very random. The least significant bit will have a
     period no more than 2, and the second bit no more than 4, etc. For
-    this reason only the high half of each X is actually used. 
+    this reason only the high half of each X is actually used.
     When a random number of more than m2exp/2 bits is to be generated,
     multiple iterations of the recurrence are used and the results
-    concatenated. 
+    concatenated.
 
    $state = fgmp_randinit_lc_2exp_size($ui);
     This is the Math::GMPf interface to the gmp library function
@@ -854,10 +856,10 @@ __END__
     Initialize state for a linear congruential algorithm as per
     gmp_randinit_lc_2exp. a, c and m2exp are selected from a table,
     chosen so that $ui bits (or more) of each X will be used,
-    ie. m2exp/2 >= $ui. 
+    ie. m2exp/2 >= $ui.
     If $ui is bigger than the table data provides then the function fails
     and dies with an appropriate error message. The maximum value for $ui
-    currently supported is 128. 
+    currently supported is 128.
 
    $state2 = fgmp_randinit_set($state1);
     This is the Math::GMPf interface to the gmp library function
@@ -880,7 +882,7 @@ __END__
     These are the Math::GMPz interfaces to the gmp library functions
     'gmp_randseed' and 'gmp_randseed_ui'.
     Seed an initialised (but not yet seeded) $state with $mpz/$ui.
-    Either Math::GMP or Math::GMPz is required for 'gmp_randseed'.   
+    Either Math::GMP or Math::GMPz is required for 'gmp_randseed'.
 
    Rmpf_urandomb(@r, $state, $bits, $how_many);
      Generate uniformly distributed random floats, all
@@ -892,7 +894,7 @@ __END__
     The exponent of the number is in the interval -$exp to $exp.
     This function is useful for testing functions and algorithms,
     since this kind of random numbers have proven to be more
-    likely to trigger corner-case bugs.  Negative random 
+    likely to trigger corner-case bugs.  Negative random
     numbers are generated when $limbs is negative.
 
    $ui = fgmp_urandomb_ui($state, $bits);
@@ -900,13 +902,13 @@ __END__
     'gmp_urandomb_ui'.
     Return a uniformly distributed random number of $bits bits, ie. in
     the range 0 to 2 ** ($bits - 1) inclusive. $bits must be less than or
-    equal to the number of bits in an unsigned long. 
+    equal to the number of bits in an unsigned long.
 
    $ui2 = fgmp_urandomm_ui($state, $ui1);
     This is the Math::GMPf interface to the gmp library function
     'gmp_urandomm_ui'.
     Return a uniformly distributed random number in the range 0 to
-    $ui1 - 1, inclusive.  
+    $ui1 - 1, inclusive.
 
    fgmp_randclear($state);
    Math::GMPz::rand_clear($state);
@@ -914,7 +916,7 @@ __END__
     identical functions.
     Use only if $state is an unblessed object - ie if it was initialised
     using Math::GMPz::rand_init() or one of the fgmp_randinit*_nobless
-    functions. 
+    functions.
 
     ####################
 
@@ -936,7 +938,7 @@ __END__
           Return value has default precision.)
      = (The copy that gets modified will have default precision.
        The other copy retains the precision of the original)
-     "" 
+     ""
 
     Atempting to use the overloaded operators with objects that
     have been blessed into some package other than 'Math::GMPf'
@@ -954,8 +956,8 @@ __END__
     to step 6:
 
     1. If the variable is an unsigned long then that value is used.
-       The variable is considered to be an unsigned long if 
-       (perl 5.8) the UOK flag is set or if (perl 5.6) SvIsUV() 
+       The variable is considered to be an unsigned long if
+       (perl 5.8) the UOK flag is set or if (perl 5.6) SvIsUV()
        returns true.
 
     2. If the variable is a signed long int, then that value is used.
@@ -1007,7 +1009,7 @@ __END__
     for the GMP library version used to build Math::GMPf. Values are
     as specified in the gmp.h that was used to build Math::GMPf.
     (These functions are in @EXPORT_OK and are therefore exportable
-    by request. They are not listed under the ":mpf" tag.) 
+    by request. They are not listed under the ":mpf" tag.)
 
    ################
 
@@ -1022,7 +1024,7 @@ __END__
      Rmpf_printf("%*Zd\n", $width, $mpz);
    we need:
      Rmpf_printf("%${width}Zd\n", $mpz);
- 
+
    $si = Rmpf_printf($format_string, $var);
 
     This function changed with the release of Math-GMPz-0.27.
@@ -1065,7 +1067,7 @@ __END__
 
    $si = Rmpf_snprintf($buffer, $bytes, $format_string, $var, $buflen);
 
-    Form a null-terminated string in $buffer. No more than $bytes 
+    Form a null-terminated string in $buffer. No more than $bytes
     bytes will be written. To get the full output, $bytes must be
     enough for the string and null-terminator. $buffer must be large
     enough to accommodate the string and null-terminator, and is
@@ -1090,18 +1092,18 @@ __END__
 
    You can get segfaults if you pass the wrong type of
    argument to the functions - so if you get a segfault, the
-   first thing to do is to check that the argument types 
+   first thing to do is to check that the argument types
    you have supplied are appropriate.
 
 =head1 LICENSE
 
-   This program is free software; you may redistribute it and/or 
+   This program is free software; you may redistribute it and/or
    modify it under the same terms as Perl itself.
-   Copyright 2006-2013 Sisyphus
+   Copyright 2006-2016 Sisyphus
 
 =head1 AUTHOR
 
    Sisyphus <sisyphus at(@) cpan dot (.) org>
 
 
-=cut
\ No newline at end of file
+=cut
